@@ -563,7 +563,7 @@ class AppSyncClient(BaseClient):
         """
 
     def start_schema_creation(
-        self, *, apiId: str, definition: Union[bytes, IO[bytes], StreamingBody]
+        self, *, apiId: str, definition: Union[str, bytes, IO[Any], StreamingBody]
     ) -> StartSchemaCreationResponseTypeDef:
         """
         Adds a new schema to your GraphQL API.
